#
# spec file for package perl-CGI-Ex
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-CGI-Ex
Version:        2.48
Release:        1.1
%define cpan_name CGI-Ex
Summary:        CGI utility suite - makes powerful application writing fun and easy
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RH/RHANDOM/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CGI)
BuildRequires:  perl(Template::Alloy) >= 1.016
Requires:       perl(CGI)
Requires:       perl(Template::Alloy) >= 1.016
%{perl_requires}

%description
CGI::Ex provides a suite of utilities to make writing CGI scripts more
enjoyable. Although they can all be used separately, the main functionality
of each of the modules is best represented in the CGI::Ex::App module.
CGI::Ex::App takes CGI application building to the next step. CGI::Ex::App
is not quite a framework (which normally includes pre-built html) instead
CGI::Ex::App is an extended application flow that dramatically reduces CGI
build time in most cases. It does so using as little magic as possible. See
CGI::Ex::App.

The main functionality is provided by several other modules that may be
used separately, or together through the CGI::Ex interface.

* 'CGI::Ex::Template'

A Template::Toolkit compatible processing engine. With a few limitations,
CGI::Ex::Template can be a drop in replacement for Template::Toolkit.

* 'CGI::Ex::Fill'

A regular expression based form filler inner (accessed through *->fill* or
directly via its own functions). Can be a drop in replacement for
HTML::FillInForm. See CGI::Ex::Fill for more information.

* 'CGI::Ex::Validate'

A form field / cgi parameter / any parameter validator (accessed through
*->validate* or directly via its own methods). Not quite a drop in for most
validators, although it has most of the functionality of most of the
validators but with the key additions of conditional validation. Has a
tightly integrated JavaScript portion that allows for duplicate client side
validation. See CGI::Ex::Validate for more information.

* 'CGI::Ex::Conf'

A general use configuration, or settings, or key / value file reader. Has
ability for providing key fallback as well as immutable key definitions.
Has default support for yaml, storable, perl, ini, and xml and open
architecture for definition of others. See CGI::Ex::Conf for more
information.

* 'CGI::Ex::Auth'

A highly configurable web based authentication system. See CGI::Ex::Auth
for more information.

%prep
%setup -q -n %{cpan_name}-%{version}
find . -type f ! -name \*.pl -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes README README.md samples

%changelog
* Sat Dec  8 2018 coolo@suse.com
- updated to 2.48
  see /usr/share/doc/packages/perl-CGI-Ex/Changes
  2.48
    2018-12-06
  * Fix app constants on modern perls.
* Sun Oct  7 2018 opensuse@dstoecker.de
- Fix automated changes
* Sat Aug 18 2018 coolo@suse.com
- updated to 2.47
  see /usr/share/doc/packages/perl-CGI-Ex/Changes
  2.47
    2018-08-16
  * Replace mechanism for setting cookies via meta tags with JavaScript equivalent (thanks to Garth Hill, Dillan Hildebrand, Alfredo Cabrera, Matt Swensen)
  * Test added for the replacement JavaScript mechanism of setting cookies
* Thu Jul 26 2018 coolo@suse.com
- updated to 2.46
  see /usr/share/doc/packages/perl-CGI-Ex/Changes
  2.46
    2018-07-24
  * Skip replace validation types in CGI::Ex::Validate when the corresponding form key's value is undef (thanks to Matt Devey)
  * Test added for CGI::Ex::Validate skipping replace validation when form key's value is undef (thanks to Charles McGarvey)
  * Removed copyright years as they weren't necessary
* Thu Aug  3 2017 coolo@suse.com
- updated to 2.45
  see /usr/share/doc/packages/perl-CGI-Ex/Changes
  2.45
    2017-07-23
  * Lost commits from 2.43 have been restored in this version
  * Allow HTML5 input types to be filled
  * Fix bug that prevents bounce_on_logout from deleting the auth cookie
  * Silence warning about CGI::param in list context
  * Fix tests on perl 5.26.0 (thanks to Petr Písař)
  * Smarter feature detection for JSON module (thanks to Petr Písař)
  * Declare perl version required
  * Add CGI.pm to pre-reqs
  * Upgrade Makefile.PL
  * No longer indexing 'samples' directory
  * Updated the copyright year to 2017
  2.44
    2015-10-07
  * Restoring the version number in several modules
  * Updated the copyright year to 2015
  2.43
    2015-10-01
  * Fixing POD errors
  * Restoring the README that got lost in 2.42
* Thu Aug 27 2015 bwiedemann@suse.com
- Require CGI as it is no more part of base perl-5.22
* Thu Apr 16 2015 coolo@suse.com
- updated to 2.42
  see /usr/share/doc/packages/perl-CGI-Ex/Changes
  2.42
    2014-12-10
  * Adding protection to location bounces to stop potential XSS vulnerabilities
  2.41
    2014-06-12
  * Restoring a tab character in Makefile.PL so that make can run again
  2.40
    2012-12-17
  * Validation fixes for regex based keys
  * Allow for HTML5 types
  * Make sure that default values always stringify
  * App find_hook now returns a list
  2.38
    2012-03-02
  * No functional changes, just fixes for newer versions of perl that have changed the way that "is" works.
  2.37
    2012-02-09
  * (Validate) Make match_2 work in the javascript layer (as shown in perldoc)
  * (Validate) Add int, uint, and num types with range checking on int and uint
  * (Validate) Allow for custom => sub { my ($k, $v) = @_; die "Always fail
  " } to pass the result of the failure via the value of die.
  * (Validate) Allow for custom_js:function (args) { throw "Always fail ("+args.value+")" } which passes the error message of the test as the fail message
  * (Validate) Allow for type, enum, and equals to short circuit (don't run match, compare, length, or custom checks if type fails)
  * (App) Fix the test suite to not require installation of CGI
  * (App) Add CGI::Ex::App::Constants module supporting constants as a source of documentation
  * (App) Allow for access to constants via use CGI::Ex::App qw(:App); or use MyApp qw(:App);
  2.36
    2010-06-10
  * (Auth) Make delete_cookie always delete, even for session Apps.
  2.35
    2010-05-24
  * (Auth) More robust cookie reading and writing and deleting.
  * Workaround CGI::Cookie->parse weird empty cookie implementation.
  * (Auth) Allow cookie_domain to be modified more gracefully.
  * (Auth) Consider case with multiple cookies for the same name.
  2.34
    2010-04-23
  * (Auth) Don't attempted to decode base64 armor unless use_base64
  2.33
    2010-04-01
  * (Auth) Allow for custom form user vs valid cookie check
* Thu Apr 14 2011 coolo@opensuse.org
- initial package 2.32
  * created by cpanspec 1.78.04
